@@ -25,6 +25,8 @@ if __name__ == "__main__" and __package__ is None:
 
 from . import __version__
 
+prog = sys.argv[0]
+
 config_ini = {
     'smtp.host': 'some.smtp.server',
     'smtp.port': '25',
@@ -65,7 +67,7 @@ def install(email, file, path, user, schedule):
     cron = CronTab(tabfile=tab_file, user=False)
     cron.remove_all()
 
-    command = f'crashalyser run --path {path}'
+    command = f'{prog} run --path {path}'
     if email:
         command = command + f' --email {email}'
     if file:
